@@ -16,9 +16,8 @@ checkAtomic = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, mi
 #' @useDynLib checkmate c_check_atomic
 #' @export
 assertAtomic = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, .var.name) {
-  makeAssertion(
-    .Call("c_check_atomic", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
-  , vname(x, .var.name))
+  res = .Call("c_check_atomic", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  makeAssertion(res, vname(x, .var.name))
 }
 
 #' @rdname checkAtomic
