@@ -19,10 +19,10 @@ checkDataFrame = function(x, types = character(0L), any.missing = TRUE, min.rows
 #' @useDynLib checkmate c_check_dataframe
 #' @export
 assertDataFrame = function(x, types = character(0L), any.missing = TRUE, min.rows = NULL, min.cols = NULL, nrows = NULL, ncols = NULL, row.names = NULL, col.names = NULL, .var.name) {
-  makeAssertion(
-    .Call("c_check_dataframe", x, any.missing, min.rows, min.cols, nrows, ncols, row.names, col.names, PACKAGE = "checkmate") %and%
-    checkListProps(x, types)
-  , vname(x, .var.name))
+  res = .Call("c_check_dataframe", x, any.missing, min.rows, min.cols, nrows, ncols, row.names, col.names, PACKAGE = "checkmate")
+  makeAssertion(res, vname(x, .var.name))
+  res = checkListProps(x, types)
+  makeAssertion(res, vname(x, .var.name))
 }
 
 #' @rdname checkDataFrame
