@@ -21,9 +21,8 @@ checkInteger = function(x, lower = -Inf, upper = Inf, any.missing = TRUE, all.mi
 #' @useDynLib checkmate c_check_integer
 #' @export
 assertInteger = function(x, lower = -Inf, upper = Inf, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, .var.name) {
-  makeAssertion(
-    .Call("c_check_integer", x, lower, upper, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
-  , vname(x, .var.name))
+  res = .Call("c_check_integer", x, lower, upper, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  makeAssertion(res, vname(x, .var.name))
 }
 
 #' @rdname checkInteger
