@@ -18,9 +18,8 @@ checkLogical = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, m
 #' @useDynLib checkmate c_check_logical
 #' @export
 assertLogical = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, .var.name) {
-  makeAssertion(
-    .Call("c_check_logical", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
-  , vname(x, .var.name))
+  res = .Call("c_check_logical", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  makeAssertion(res, vname(x, .var.name))
 }
 
 #' @rdname checkLogical
