@@ -37,9 +37,8 @@ checkMatrix = function(x, mode = NULL, any.missing = TRUE, min.rows = NULL, min.
 #' @useDynLib checkmate c_check_matrix
 #' @export
 assertMatrix = function(x, mode = NULL, any.missing = TRUE, min.rows = NULL, min.cols = NULL, nrows = NULL, ncols = NULL, row.names = NULL, col.names = NULL, .var.name) {
-  makeAssertion(
-    .Call("c_check_matrix", x, mode, any.missing, min.rows, min.cols, nrows, ncols, row.names, col.names, PACKAGE = "checkmate")
-  , vname(x, .var.name))
+  res = .Call("c_check_matrix", x, mode, any.missing, min.rows, min.cols, nrows, ncols, row.names, col.names, PACKAGE = "checkmate")
+  makeAssertion(res, vname(x, .var.name))
 }
 
 #' @rdname checkMatrix
